@@ -885,7 +885,7 @@ static int signal_gain_setting(struct audio_device *device, const char *buf)
 				DBUS_TYPE_UINT16, &gain,
 				DBUS_TYPE_INVALID);
 
-	dbus_connection_emit_property_changed(device->conn, device->path,
+	emit_property_changed(device->conn, device->path,
 				AUDIO_HEADSET_INTERFACE, property,
 				DBUS_TYPE_UINT16, &gain);
 
@@ -1681,17 +1681,17 @@ done:
 	if (type == HEADSET_GAIN_SPEAKER) {
 		hs->sp_gain = gain;
 		g_dbus_emit_signal(conn, device->path,
-						AUDIO_HEADSET_INTERFACE,
-						"SpeakerGainChanged",
-						DBUS_TYPE_UINT16, &gain,
-						DBUS_TYPE_INVALID);
+					AUDIO_HEADSET_INTERFACE,
+					"SpeakerGainChanged",
+					DBUS_TYPE_UINT16, &gain,
+					DBUS_TYPE_INVALID);
 	} else {
 		hs->mic_gain = gain;
 		g_dbus_emit_signal(conn, device->path,
-						AUDIO_HEADSET_INTERFACE,
-						"MicrophoneGainChanged",
-						DBUS_TYPE_UINT16, &gain,
-						DBUS_TYPE_INVALID);
+					AUDIO_HEADSET_INTERFACE,
+					"MicrophoneGainChanged",
+					DBUS_TYPE_UINT16, &gain,
+					DBUS_TYPE_INVALID);
 	}
 
 	return reply;
@@ -1746,26 +1746,22 @@ static DBusMessage *hs_get_properties(DBusConnection *conn,
 
 	/* Playing */
 	value = (device->headset->state == HEADSET_STATE_PLAYING);
-	dbus_message_iter_append_dict_entry(&dict, "Playing",
-						DBUS_TYPE_BOOLEAN, &value);
+	dict_append_entry(&dict, "Playing", DBUS_TYPE_BOOLEAN, &value);
 
 	/* Connected */
 	value = (device->headset->state >= HEADSET_STATE_CONNECTED);
-	dbus_message_iter_append_dict_entry(&dict, "Connected",
-						DBUS_TYPE_BOOLEAN, &value);
+	dict_append_entry(&dict, "Connected", DBUS_TYPE_BOOLEAN, &value);
 
 	if (!value)
 		goto done;
 
 	/* SpeakerGain */
-	dbus_message_iter_append_dict_entry(&dict, "SpeakerGain",
-						DBUS_TYPE_UINT16,
-						&device->headset->sp_gain);
+	dict_append_entry(&dict, "SpeakerGain",
+				DBUS_TYPE_UINT16, &device->headset->sp_gain);
 
 	/* MicrophoneGain */
-	dbus_message_iter_append_dict_entry(&dict, "MicrophoneGain",
-						DBUS_TYPE_UINT16,
-						&device->headset->mic_gain);
+	dict_append_entry(&dict, "MicrophoneGain",
+				DBUS_TYPE_UINT16, &device->headset->mic_gain);
 
 done:
 	dbus_message_iter_close_container(&iter, &dict);
@@ -2220,13 +2216,12 @@ void headset_set_state(struct audio_device *dev, headset_state_t state)
 		close_sco(dev);
 		headset_close_rfcomm(dev);
 		g_dbus_emit_signal(dev->conn, dev->path,
-						AUDIO_HEADSET_INTERFACE,
-						"Disconnected",
-						DBUS_TYPE_INVALID);
-		dbus_connection_emit_property_changed(dev->conn, dev->path,
-						AUDIO_HEADSET_INTERFACE,
-						"Connected",
-						DBUS_TYPE_BOOLEAN, &value);
+					AUDIO_HEADSET_INTERFACE,
+					"Disconnected",
+					DBUS_TYPE_INVALID);
+		emit_property_changed(dev->conn, dev->path,
+					AUDIO_HEADSET_INTERFACE, "Connected",
+					DBUS_TYPE_BOOLEAN, &value);
 		telephony_device_disconnected(dev);
 		active_devices = g_slist_remove(active_devices, dev);
 		break;
@@ -2240,7 +2235,7 @@ void headset_set_state(struct audio_device *dev, headset_state_t state)
 						AUDIO_HEADSET_INTERFACE,
 						"Connected",
 						DBUS_TYPE_INVALID);
-			dbus_connection_emit_property_changed(dev->conn, dev->path,
+			emit_property_changed(dev->conn, dev->path,
 						AUDIO_HEADSET_INTERFACE,
 						"Connected",
 						DBUS_TYPE_BOOLEAN, &value);
@@ -2252,7 +2247,7 @@ void headset_set_state(struct audio_device *dev, headset_state_t state)
 						AUDIO_HEADSET_INTERFACE,
 						"Stopped",
 						DBUS_TYPE_INVALID);
-			dbus_connection_emit_property_changed(dev->conn, dev->path,
+			emit_property_changed(dev->conn, dev->path,
 						AUDIO_HEADSET_INTERFACE,
 						"Playing",
 						DBUS_TYPE_BOOLEAN, &value);
@@ -2267,12 +2262,11 @@ void headset_set_state(struct audio_device *dev, headset_state_t state)
 					(GIOFunc) sco_cb, dev);
 
 		g_dbus_emit_signal(dev->conn, dev->path,
-						AUDIO_HEADSET_INTERFACE,
-						"Playing", DBUS_TYPE_INVALID);
-		dbus_connection_emit_property_changed(dev->conn, dev->path,
-						AUDIO_HEADSET_INTERFACE,
-						"Playing",
-						DBUS_TYPE_BOOLEAN, &value);
+					AUDIO_HEADSET_INTERFACE, "Playing",
+					DBUS_TYPE_INVALID);
+		emit_property_changed(dev->conn, dev->path,
+					AUDIO_HEADSET_INTERFACE, "Playing",
+					DBUS_TYPE_BOOLEAN, &value);
 
 		if (hs->sp_gain >= 0)
 			headset_send(hs, "\r\n+VGS=%u\r\n", hs->sp_gain);
